@@ -18,6 +18,7 @@ package format
 
 import (
 	"bytes"
+	"go/types"
 	"path"
 	"strconv"
 
@@ -142,16 +143,35 @@ type importCtx struct {
 
 type formatCtx struct {
 	imports map[string]*importCtx
+	scope   *types.Scope
+}
+
+func (ctx *formatCtx) insert(name string) {
+	o := types.NewParam(token.NoPos, nil, name, types.Typ[types.UntypedNil])
+	ctx.scope.Insert(o)
+}
+
+func (ctx *formatCtx) enterBlock() *types.Scope {
+	old := ctx.scope
+	ctx.scope = types.NewScope(old, token.NoPos, token.NoPos, "")
+	return old
+}
+
+func (ctx *formatCtx) leaveBlock(old *types.Scope) {
+	ctx.scope = old
 }
 
 func formatFile(file *ast.File) {
+	var funcs []*ast.FuncDecl
 	ctx := &formatCtx{
 		imports: make(map[string]*importCtx),
+		scope:   types.NewScope(nil, token.NoPos, token.NoPos, ""),
 	}
 	for _, decl := range file.Decls {
 		switch v := decl.(type) {
 		case *ast.FuncDecl:
-			formatFuncDecl(ctx, v)
+			// delay the process, because package level vars need to be processed first.
+			funcs = append(funcs, v)
 		case *ast.GenDecl:
 			switch v.Tok {
 			case token.IMPORT:
@@ -174,6 +194,10 @@ func formatFile(file *ast.File) {
 			}
 		}
 	}
+
+	for _, fn := range funcs {
+		formatFuncDecl(ctx, fn)
+	}
 	for _, imp := range ctx.imports {
 		if imp.pkgPath == "fmt" && !imp.isUsed {
 			if len(imp.decl.Specs) == 1 {
@@ -192,6 +216,9 @@ func formatGenDecl(ctx *formatCtx, v *ast.GenDecl) {
 			spec := item.(*ast.ValueSpec)
 			formatType(ctx, spec.Type, &spec.Type)
 			formatExprs(ctx, spec.Values)
+			for _, name := range spec.Names {
+				ctx.insert(name.Name)
+			}
 		}
 	case token.TYPE:
 		for _, item := range v.Specs {
@@ -206,4 +233,43 @@ func formatFuncDecl(ctx *formatCtx, v *ast.FuncDecl) {
 	formatBlockStmt(ctx, v.Body)
 }
 
+/*
+func fillVarCtx(ctx *formatCtx, spec *ast.ValueSpec) {
+	for _, name := range spec.Names {
+		ctx.scp.addVar(name.Name)
+	}
+}
+
+type scope struct {
+	vars []map[string]bool
+}
+
+func newScope() *scope {
+	return &scope{
+		vars: []map[string]bool{make(map[string]bool)},
+	}
+}
+
+func (s *scope) addVar(name string) {
+	s.vars[len(s.vars)-1][name] = true
+}
+
+func (s *scope) containsVar(name string) bool {
+	for _, m := range s.vars {
+		if m[name] {
+			return true
+		}
+	}
+
+	return false
+}
+
+func (s *scope) enterScope() {
+	s.vars = append(s.vars, make(map[string]bool))
+}
+
+func (s *scope) exitScope() {
+	s.vars = s.vars[:len(s.vars)-1]
+}
+*/
 // -----------------------------------------------------------------------------
